==> flask_exts-0.1.7.tar.gz: flask_exts-0.1.7/examples/bootstrap5/app.py <==
from enum import Enum
from flask import Flask, render_template, request, flash, redirect, url_for
from flask import current_app
from markupsafe import Markup
from wtforms.validators import DataRequired, Length, Regexp
from wtforms.fields import *
from flask_sqlalchemy import SQLAlchemy

from flask_exts.forms.form import FlaskForm
from flask_exts.forms.fields.switch import SwitchField
from flask_exts import Manager
from flask_exts.templating.theme import DefaultTheme

theme = DefaultTheme(bootstrap_version=5)

manager = Manager()
app = Flask(__name__)
app.secret_key = "dev"

app.config["SQLALCHEMY_TRACK_MODIFICATIONS"] = False
app.config["SQLALCHEMY_DATABASE_URI"] = "sqlite:///:memory:"
# set bootstrap5
app.config["TEMPLATE_THEME"] = theme

manager.init_app(app)
db = SQLAlchemy(app)


class ExampleForm(FlaskForm):
    """An example form that contains all the supported bootstrap style form fields."""

    date = DateField(
        description="We'll never share your email with anyone else."
    )  # add help text with `description`
    datetime = DateTimeField(
        render_kw={"placeholder": "this is a placeholder"}
    )  # add HTML attribute with `render_kw`
    datetime_local = DateTimeLocalField()
    time = TimeField()
    month = MonthField()
    color = ColorField()
    floating = FloatField()
    integer = IntegerField()
    decimal_slider = DecimalRangeField()
    integer_slider = IntegerRangeField(render_kw={"min": "0", "max": "4"})
    email = EmailField()
    url = URLField()
    telephone = TelField()
    image = FileField(
        render_kw={"class": "my-class"}, validators=[Regexp(".+\.jpg$")]
    )  # add your class
    option = RadioField(
        choices=[("dog", "Dog"), ("cat", "Cat"), ("bird", "Bird"), ("alien", "Alien")]
    )
    select = SelectField(
        choices=[("dog", "Dog"), ("cat", "Cat"), ("bird", "Bird"), ("alien", "Alien")]
    )
    select_multiple = SelectMultipleField(
        choices=[("dog", "Dog"), ("cat", "Cat"), ("bird", "Bird"), ("alien", "Alien")]
    )
    bio = TextAreaField()
    search = SearchField()  # will autocapitalize on mobile
    title = StringField()  # will not autocapitalize on mobile
    secret = PasswordField()
    remember = BooleanField("Remember me")
    submit = SubmitField()


class HelloForm(FlaskForm):
    username = StringField("Username", validators=[DataRequired(), Length(1, 20)])
    password = PasswordField("Password", validators=[DataRequired(), Length(8, 150)])
    remember = BooleanField("Remember me")
    submit = SubmitField()


class ButtonForm(FlaskForm):
    username = StringField("Username", validators=[DataRequired(), Length(1, 20)])
    confirm = SwitchField("Confirmation")
    submit = SubmitField()
    delete = SubmitField()
    cancel = SubmitField()


class TelephoneForm(FlaskForm):
    country_code = IntegerField("Country Code")
    area_code = IntegerField("Area Code/Exchange")
    number = StringField("Number")


class IMForm(FlaskForm):
    protocol = SelectField(choices=[("aim", "AIM"), ("msn", "MSN")])
    username = StringField()


class ContactForm(FlaskForm):
    first_name = StringField()
    last_name = StringField()
    mobile_phone = FormField(TelephoneForm)
    office_phone = FormField(TelephoneForm)
    emails = FieldList(StringField("Email"), min_entries=3)
    im_accounts = FieldList(FormField(IMForm), min_entries=2)


class BootswatchForm(FlaskForm):
    """Form to test Bootswatch."""

    # DO NOT EDIT! Use list-bootswatch.py to generate the Radiofield below.
    theme_name = RadioField(
        default="default",
        choices=[
            ("default", "none"),
            ("cerulean", "Cerulean 5.3.1"),
            ("cosmo", "Cosmo 5.3.1"),
            ("cyborg", "Cyborg 5.3.1"),
            ("darkly", "Darkly 5.3.1"),
            ("flatly", "Flatly 5.3.1"),
            ("journal", "Journal 5.3.1"),
            ("litera", "Litera 5.3.1"),
            ("lumen", "Lumen 5.3.1"),
            ("lux", "Lux 5.3.1"),
            ("materia", "Materia 5.3.1"),
            ("minty", "Minty 5.3.1"),
            ("morph", "Morph 5.3.1"),
            ("pulse", "Pulse 5.3.1"),
            ("quartz", "Quartz 5.3.1"),
            ("sandstone", "Sandstone 5.3.1"),
            ("simplex", "Simplex 5.3.1"),
            ("sketchy", "Sketchy 5.3.1"),
            ("slate", "Slate 5.3.1"),
            ("solar", "Solar 5.3.1"),
            ("spacelab", "Spacelab 5.3.1"),
            ("superhero", "Superhero 5.3.1"),
            ("united", "United 5.3.1"),
            ("vapor", "Vapor 5.3.1"),
            ("yeti", "Yeti 5.3.1"),
            ("zephyr", "Zephyr 5.3.1"),
        ],
    )
    submit = SubmitField()


class MyCategory(Enum):
    CAT1 = "Category 1"
    CAT2 = "Category 2"


class Message(db.Model):
    id = db.Column(db.Integer, primary_key=True)
    text = db.Column(db.Text, nullable=False)
    author = db.Column(db.String(100), nullable=False)
    category = db.Column(db.Enum(MyCategory), default=MyCategory.CAT1, nullable=False)
    draft = db.Column(db.Boolean, default=False, nullable=False)
    create_time = db.Column(db.Integer, nullable=False, unique=True)


with app.app_context():
    db.drop_all()
    db.create_all()
    for i in range(20):
        url = "mailto:x@t.me"
        if i % 7 == 0:
            url = "www.t.me"
        elif i % 7 == 1:
            url = "https://t.me"
        elif i % 7 == 2:
            url = "http://t.me"
        elif i % 7 == 3:
            url = "http://t"
        elif i % 7 == 4:
            url = "http://"
        elif i % 7 == 5:
            url = "x@t.me"
        m = Message(
            text=f"Message {i+1} {url}",
            author=f"Author {i+1}",
            create_time=4321 * (i + 1),
        )
        if i % 2:
            m.category = MyCategory.CAT2
        if i % 4:
            m.draft = True
        db.session.add(m)
    db.session.commit()


@app.route("/")
def index():
    return render_template("index.html")


@app.route("/form", methods=["GET", "POST"])
def test_form():
    form = HelloForm()
    if form.validate_on_submit():
        flash("Form validated!")
        return redirect(url_for("index"))
    return render_template(
        "form.html",
        form=form,
        telephone_form=TelephoneForm(),
        contact_form=ContactForm(),
        im_form=IMForm(),
        button_form=ButtonForm(),
        example_form=ExampleForm(),
    )


@app.route("/nav", methods=["GET", "POST"])
def test_nav():
    return render_template("nav.html")


@app.route("/bootswatch", methods=["GET", "POST"])
def test_bootswatch():
    form = BootswatchForm()
    if form.validate_on_submit():
        flash(f"Render style has been set to {form.theme_name.data}.")
    return render_template("bootswatch.html", form=form)


@app.route("/pagination", methods=["GET", "POST"])
def test_pagination():
    page = request.args.get("page", 1, type=int)
    pagination = Message.query.paginate(page=page, per_page=10)
    messages = pagination.items
    return render_template("pagination.html", pagination=pagination, messages=messages)


@app.route("/flash", methods=["GET", "POST"])
def test_flash():
    flash("A simple default alert—check it out!")
    flash("A simple primary alert—check it out!", "primary")
    flash("A simple secondary alert—check it out!", "secondary")
    flash("A simple success alert—check it out!", "success")
    flash("A simple danger alert—check it out!", "danger")
    flash("A simple warning alert—check it out!", "warning")
    flash("A simple info alert—check it out!", "info")
    flash("A simple light alert—check it out!", "light")
    flash("A simple dark alert—check it out!", "dark")
    flash(
        Markup(
            'A simple success alert with <a href="#" class="alert-link">an example link</a>. Give it a click if you like.'
        ),
        "success",
    )
    return render_template("flash.html")


@app.route("/table")
def test_table():
    page = request.args.get("page", 1, type=int)
    pagination = Message.query.paginate(page=page, per_page=10)
    messages = pagination.items
    titles = [
        ("id", "#"),
        ("text", "Message"),
        ("author", "Author"),
        ("category", "Category"),
        ("draft", "Draft"),
        ("create_time", "Create Time"),
    ]
    data = []
    for msg in messages:
        data.append(
            {
                "id": msg.id,
                "text": msg.text,
                "author": msg.author,
                "category": msg.category,
                "draft": msg.draft,
                "create_time": msg.create_time,
            }
        )
    return render_template(
        "table.html", messages=messages, titles=titles, Message=Message, data=data
    )


@app.route("/table/<int:message_id>/view")
def view_message(message_id):
    message = Message.query.get(message_id)
    if message:
        return f'Viewing {message_id} with text "{message.text}". Return to <a href="/table">table</a>.'
    return f'Could not view message {message_id} as it does not exist. Return to <a href="/table">table</a>.'


@app.route("/table/<int:message_id>/edit")
def edit_message(message_id):
    message = Message.query.get(message_id)
    if message:
        message.draft = not message.draft
        db.session.commit()
        return f'Message {message_id} has been editted by toggling draft status. Return to <a href="/table">table</a>.'
    return f'Message {message_id} did not exist and could therefore not be edited. Return to <a href="/table">table</a>.'


@app.route("/table/<int:message_id>/delete", methods=["POST"])
def delete_message(message_id):
    message = Message.query.get(message_id)
    if message:
        db.session.delete(message)
        db.session.commit()
        return f'Message {message_id} has been deleted. Return to <a href="/table">table</a>.'
    return f'Message {message_id} did not exist and could therefore not be deleted. Return to <a href="/table">table</a>.'


@app.route("/table/<int:message_id>/like")
def like_message(message_id):
    return f'Liked the message {message_id}. Return to <a href="/table">table</a>.'


@app.route("/table/new-message")
def new_message():
    return 'Here is the new message page. Return to <a href="/table">table</a>.'


@app.route("/icon")
def test_icon():
    return render_template("icon.html")


@app.route("/icons")
def test_icons():
    return render_template("icons.html")


if __name__ == "__main__":
    app.run(debug=True)

==> flask_exts-0.1.9.tar.gz: flask_exts-0.1.9/examples/bootstrap5/app.py <==
from enum import Enum
from flask import Flask, render_template, request, flash, redirect, url_for
from flask import current_app
from markupsafe import Markup
from wtforms.validators import DataRequired, Length, Regexp
from wtforms.fields import *
from flask_sqlalchemy import SQLAlchemy

from flask_exts.forms.form import FlaskForm
from python_plugins.forms.fields.switch import SwitchField
from flask_exts import Manager
from flask_exts.templating.theme import DefaultTheme

theme = DefaultTheme(bootstrap_version=5)

manager = Manager()
app = Flask(__name__)
app.secret_key = "dev"

app.config["SQLALCHEMY_TRACK_MODIFICATIONS"] = False
app.config["SQLALCHEMY_DATABASE_URI"] = "sqlite:///:memory:"
# set bootstrap5
app.config["TEMPLATE_THEME"] = theme

manager.init_app(app)
db = SQLAlchemy(app)


class ExampleForm(FlaskForm):
    """An example form that contains all the supported bootstrap style form fields."""

    date = DateField(
        description="We'll never share your email with anyone else."
    )  # add help text with `description`
    datetime = DateTimeField(
        render_kw={"placeholder": "this is a placeholder"}
    )  # add HTML attribute with `render_kw`
    datetime_local = DateTimeLocalField()
    time = TimeField()
    month = MonthField()
    color = ColorField()
    floating = FloatField()
    integer = IntegerField()
    decimal_slider = DecimalRangeField()
    integer_slider = IntegerRangeField(render_kw={"min": "0", "max": "4"})
    email = EmailField()
    url = URLField()
    telephone = TelField()
    image = FileField(
        render_kw={"class": "my-class"}, validators=[Regexp(r".+\.jpg$")]
    )  # add your class
    option = RadioField(
        choices=[("dog", "Dog"), ("cat", "Cat"), ("bird", "Bird"), ("alien", "Alien")]
    )
    select = SelectField(
        choices=[("dog", "Dog"), ("cat", "Cat"), ("bird", "Bird"), ("alien", "Alien")]
    )
    select_multiple = SelectMultipleField(
        choices=[("dog", "Dog"), ("cat", "Cat"), ("bird", "Bird"), ("alien", "Alien")]
    )
    bio = TextAreaField()
    search = SearchField()  # will autocapitalize on mobile
    title = StringField()  # will not autocapitalize on mobile
    secret = PasswordField()
    remember = BooleanField("Remember me")
    submit = SubmitField()


class HelloForm(FlaskForm):
    username = StringField("Username", validators=[DataRequired(), Length(1, 20)])
    password = PasswordField("Password", validators=[DataRequired(), Length(8, 150)])
    remember = BooleanField("Remember me")
    submit = SubmitField()


class ButtonForm(FlaskForm):
    username = StringField("Username", validators=[DataRequired(), Length(1, 20)])
    confirm = SwitchField("Confirmation")
    submit = SubmitField()
    delete = SubmitField()
    cancel = SubmitField()


class TelephoneForm(FlaskForm):
    country_code = IntegerField("Country Code")
    area_code = IntegerField("Area Code/Exchange")
    number = StringField("Number")


class IMForm(FlaskForm):
    protocol = SelectField(choices=[("aim", "AIM"), ("msn", "MSN")])
    username = StringField()


class ContactForm(FlaskForm):
    first_name = StringField()
    last_name = StringField()
    mobile_phone = FormField(TelephoneForm)
    office_phone = FormField(TelephoneForm)
    emails = FieldList(StringField("Email"), min_entries=3)
    im_accounts = FieldList(FormField(IMForm), min_entries=2)


class BootswatchForm(FlaskForm):
    """Form to test Bootswatch."""

    # DO NOT EDIT! Use list-bootswatch.py to generate the Radiofield below.
    theme_name = RadioField(
        default="default",
        choices=[
            ("default", "none"),
            ("cerulean", "Cerulean 5.3.1"),
            ("cosmo", "Cosmo 5.3.1"),
            ("cyborg", "Cyborg 5.3.1"),
            ("darkly", "Darkly 5.3.1"),
            ("flatly", "Flatly 5.3.1"),
            ("journal", "Journal 5.3.1"),
            ("litera", "Litera 5.3.1"),
            ("lumen", "Lumen 5.3.1"),
            ("lux", "Lux 5.3.1"),
            ("materia", "Materia 5.3.1"),
            ("minty", "Minty 5.3.1"),
            ("morph", "Morph 5.3.1"),
            ("pulse", "Pulse 5.3.1"),
            ("quartz", "Quartz 5.3.1"),
            ("sandstone", "Sandstone 5.3.1"),
            ("simplex", "Simplex 5.3.1"),
            ("sketchy", "Sketchy 5.3.1"),
            ("slate", "Slate 5.3.1"),
            ("solar", "Solar 5.3.1"),
            ("spacelab", "Spacelab 5.3.1"),
            ("superhero", "Superhero 5.3.1"),
            ("united", "United 5.3.1"),
            ("vapor", "Vapor 5.3.1"),
            ("yeti", "Yeti 5.3.1"),
            ("zephyr", "Zephyr 5.3.1"),
        ],
    )
    submit = SubmitField()


class MyCategory(Enum):
    CAT1 = "Category 1"
    CAT2 = "Category 2"


class Message(db.Model):
    id = db.Column(db.Integer, primary_key=True)
    text = db.Column(db.Text, nullable=False)
    author = db.Column(db.String(100), nullable=False)
    category = db.Column(db.Enum(MyCategory), default=MyCategory.CAT1, nullable=False)
    draft = db.Column(db.Boolean, default=False, nullable=False)
    create_time = db.Column(db.Integer, nullable=False, unique=True)


with app.app_context():
    db.drop_all()
    db.create_all()
    for i in range(20):
        url = "mailto:x@t.me"
        if i % 7 == 0:
            url = "www.t.me"
        elif i % 7 == 1:
            url = "https://t.me"
        elif i % 7 == 2:
            url = "http://t.me"
        elif i % 7 == 3:
            url = "http://t"
        elif i % 7 == 4:
            url = "http://"
        elif i % 7 == 5:
            url = "x@t.me"
        m = Message(
            text=f"Message {i+1} {url}",
            author=f"Author {i+1}",
            create_time=4321 * (i + 1),
        )
        if i % 2:
            m.category = MyCategory.CAT2
        if i % 4:
            m.draft = True
        db.session.add(m)
    db.session.commit()


@app.route("/")
def index():
    return render_template("index.html")


@app.route("/form", methods=["GET", "POST"])
def test_form():
    form = HelloForm()
    if form.validate_on_submit():
        flash("Form validated!")
        return redirect(url_for("index"))
    return render_template(
        "form.html",
        form=form,
        telephone_form=TelephoneForm(),
        contact_form=ContactForm(),
        im_form=IMForm(),
        button_form=ButtonForm(),
        example_form=ExampleForm(),
    )


@app.route("/nav", methods=["GET", "POST"])
def test_nav():
    return render_template("nav.html")


@app.route("/bootswatch", methods=["GET", "POST"])
def test_bootswatch():
    form = BootswatchForm()
    if form.validate_on_submit():
        flash(f"Render style has been set to {form.theme_name.data}.")
    return render_template("bootswatch.html", form=form)


@app.route("/pagination", methods=["GET", "POST"])
def test_pagination():
    page = request.args.get("page", 1, type=int)
    pagination = Message.query.paginate(page=page, per_page=10)
    messages = pagination.items
    return render_template("pagination.html", pagination=pagination, messages=messages)


@app.route("/flash", methods=["GET", "POST"])
def test_flash():
    flash("A simple default alert—check it out!")
    flash("A simple primary alert—check it out!", "primary")
    flash("A simple secondary alert—check it out!", "secondary")
    flash("A simple success alert—check it out!", "success")
    flash("A simple danger alert—check it out!", "danger")
    flash("A simple warning alert—check it out!", "warning")
    flash("A simple info alert—check it out!", "info")
    flash("A simple light alert—check it out!", "light")
    flash("A simple dark alert—check it out!", "dark")
    flash(
        Markup(
            'A simple success alert with <a href="#" class="alert-link">an example link</a>. Give it a click if you like.'
        ),
        "success",
    )
    return render_template("flash.html")


@app.route("/table")
def test_table():
    page = request.args.get("page", 1, type=int)
    pagination = Message.query.paginate(page=page, per_page=10)
    messages = pagination.items
    titles = [
        ("id", "#"),
        ("text", "Message"),
        ("author", "Author"),
        ("category", "Category"),
        ("draft", "Draft"),
        ("create_time", "Create Time"),
    ]
    data = []
    for msg in messages:
        data.append(
            {
                "id": msg.id,
                "text": msg.text,
                "author": msg.author,
                "category": msg.category,
                "draft": msg.draft,
                "create_time": msg.create_time,
            }
        )
    return render_template(
        "table.html", messages=messages, titles=titles, Message=Message, data=data
    )


@app.route("/table/<int:message_id>/view")
def view_message(message_id):
    message = Message.query.get(message_id)
    if message:
        return f'Viewing {message_id} with text "{message.text}". Return to <a href="/table">table</a>.'
    return f'Could not view message {message_id} as it does not exist. Return to <a href="/table">table</a>.'


@app.route("/table/<int:message_id>/edit")
def edit_message(message_id):
    message = Message.query.get(message_id)
    if message:
        message.draft = not message.draft
        db.session.commit()
        return f'Message {message_id} has been editted by toggling draft status. Return to <a href="/table">table</a>.'
    return f'Message {message_id} did not exist and could therefore not be edited. Return to <a href="/table">table</a>.'


@app.route("/table/<int:message_id>/delete", methods=["POST"])
def delete_message(message_id):
    message = Message.query.get(message_id)
    if message:
        db.session.delete(message)
        db.session.commit()
        return f'Message {message_id} has been deleted. Return to <a href="/table">table</a>.'
    return f'Message {message_id} did not exist and could therefore not be deleted. Return to <a href="/table">table</a>.'


@app.route("/table/<int:message_id>/like")
def like_message(message_id):
    return f'Liked the message {message_id}. Return to <a href="/table">table</a>.'


@app.route("/table/new-message")
def new_message():
    return 'Here is the new message page. Return to <a href="/table">table</a>.'


@app.route("/icon")
def test_icon():
    return render_template("icon.html")


@app.route("/icons")
def test_icons():
    return render_template("icons.html")


if __name__ == "__main__":
    app.run(debug=True)
